data_layer_hive library

Classes

HiveCache<T>
Persists various records to Hive boxes.
HiveInitializer
Helper to initialize Hive bindings.
HiveOperationsPersistence<T>
Durable persistence engine for failed operations using Hive. This is most suited for write operations which you want to try again later, such as to provide offline support which queues up writes for when connectivity is restored; even if that is after a fresh launch of the app.
HiveSource<T>
Implements LocalSource using Hive.